@@ -38,6 +38,7 @@ import org.apache.roller.weblogger.pojos.WeblogEntry.PubStatus;
 import org.apache.roller.util.UUIDGenerator;
 import org.apache.roller.weblogger.business.UserManager;
 import org.apache.roller.weblogger.util.I18nUtils;
+import org.apache.roller.weblogger.util.Utilities;
 
 
 /**
@@ -62,7 +63,7 @@ public class Weblog implements Serializable {
     private String  tagline          = null;
     private Boolean enableBloggerApi = Boolean.TRUE;
     private String  editorPage       = null;
-    private String  blacklist        = null;
+    private String  bannedwordslist  = null;
     private Boolean allowComments    = Boolean.TRUE;
     private Boolean emailComments    = Boolean.FALSE;
     private String  emailAddress     = null;
@@ -90,11 +91,11 @@ public class Weblog implements Serializable {
 
     private Map<String, WeblogEntryPlugin> initializedPlugins = null;
 
-    private List<WeblogCategory> weblogCategories = new ArrayList<WeblogCategory>();
+    private List<WeblogCategory> weblogCategories = new ArrayList<>();
 
-    private List<WeblogBookmarkFolder> bookmarkFolders = new ArrayList<WeblogBookmarkFolder>();
+    private List<WeblogBookmarkFolder> bookmarkFolders = new ArrayList<>();
 
-    private List<MediaFileDirectory> mediaFileDirectories = new ArrayList<MediaFileDirectory>();
+    private List<MediaFileDirectory> mediaFileDirectories = new ArrayList<>();
 
     public Weblog() {
     }
@@ -121,12 +122,14 @@ public class Weblog implements Serializable {
     
     //------------------------------------------------------- Good citizenship
 
+    @Override
     public String toString() {
         return  "{" + getId() + ", " + getHandle()
         + ", " + getName() + ", " + getEmailAddress()
         + ", " + getLocale() + ", " + getTimeZone() + "}";
     }
 
+    @Override
     public boolean equals(Object other) {
         if (other == this) {
             return true;
@@ -140,6 +143,7 @@ public class Weblog implements Serializable {
             .isEquals();
     }
     
+    @Override
     public int hashCode() { 
         return new HashCodeBuilder()
             .append(getHandle())
@@ -192,7 +196,7 @@ public class Weblog implements Serializable {
     }
     
     public void setName(String name) {
-        this.name = name;
+        this.name = Utilities.removeHTML(name);
     }
     
     /**
@@ -204,7 +208,7 @@ public class Weblog implements Serializable {
     }
     
     public void setTagline(String tagline) {
-        this.tagline = tagline;
+        this.tagline = Utilities.removeHTML(tagline);
     }
     
     /**
@@ -252,12 +256,12 @@ public class Weblog implements Serializable {
         this.editorPage = editorPage;
     }
     
-    public String getBlacklist() {
-        return this.blacklist;
+    public String getBannedwordslist() {
+        return this.bannedwordslist;
     }
     
-    public void setBlacklist(String blacklist) {
-        this.blacklist = blacklist;
+    public void setBannedwordslist(String bannedwordslist) {
+        this.bannedwordslist = bannedwordslist;
     }
     
     public Boolean getAllowComments() {
@@ -381,7 +385,7 @@ public class Weblog implements Serializable {
         this.setEnableBloggerApi(other.getEnableBloggerApi());
         this.setBloggerCategory(other.getBloggerCategory());
         this.setEditorPage(other.getEditorPage());
-        this.setBlacklist(other.getBlacklist());
+        this.setBannedwordslist(other.getBannedwordslist());
         this.setAllowComments(other.getAllowComments());
         this.setEmailComments(other.getEmailComments());
         this.setEmailAddress(other.getEmailAddress());
@@ -564,7 +568,7 @@ public class Weblog implements Serializable {
     /**
      * A description for the weblog (its purpose, authors, etc.)
      *
-     * This field is meant to hold a paragraph or two describing the weblog, in contrast
+     * This field is meant to hold a paragraph describing the weblog, in contrast
      * to the short sentence or two 'description' attribute meant for blog taglines
      * and HTML header META description tags.
      *
@@ -574,7 +578,7 @@ public class Weblog implements Serializable {
     }
 
     public void setAbout(String about) {
-        this.about = about;
+        this.about = Utilities.removeHTML(about);
     }
     
     
@@ -641,9 +645,8 @@ public class Weblog implements Serializable {
         if (length > MAX_ENTRIES) {
             length = MAX_ENTRIES;
         }
-        List<WeblogEntry> recentEntries = new ArrayList<WeblogEntry>();
         if (length < 1) {
-            return recentEntries;
+            return Collections.emptyList();
         }
         try {
             WeblogEntryManager wmgr = WebloggerFactory.getWeblogger().getWeblogEntryManager();
@@ -652,11 +655,11 @@ public class Weblog implements Serializable {
             wesc.setCatName(cat);
             wesc.setStatus(PubStatus.PUBLISHED);
             wesc.setMaxResults(length);
-            recentEntries = wmgr.getWeblogEntries(wesc);
+            return wmgr.getWeblogEntries(wesc);
         } catch (WebloggerException e) {
             log.error("ERROR: getting recent entries", e);
         }
-        return recentEntries;
+        return Collections.emptyList();
     }
     
     /**
@@ -672,13 +675,12 @@ public class Weblog implements Serializable {
         if (length > MAX_ENTRIES) {
             length = MAX_ENTRIES;
         }
-        List<WeblogEntry> recentEntries = new ArrayList<WeblogEntry>();
-        List<String> tags = new ArrayList<String>();
-        if (tag != null) {
-            tags.add(tag);
-        }
         if (length < 1) {
-            return recentEntries;
+            return Collections.emptyList();
+        }
+        List<String> tags = Collections.emptyList();
+        if (tag != null) {
+            tags = List.of(tag);
         }
         try {
             WeblogEntryManager wmgr = WebloggerFactory.getWeblogger().getWeblogEntryManager();
@@ -687,11 +689,11 @@ public class Weblog implements Serializable {
             wesc.setTags(tags);
             wesc.setStatus(PubStatus.PUBLISHED);
             wesc.setMaxResults(length);
-            recentEntries = wmgr.getWeblogEntries(wesc);
+            return wmgr.getWeblogEntries(wesc);
         } catch (WebloggerException e) {
             log.error("ERROR: getting recent entries", e);
         }
-        return recentEntries;
+        return Collections.emptyList();
     }   
     
     /**
@@ -703,9 +705,8 @@ public class Weblog implements Serializable {
         if (length > MAX_ENTRIES) {
             length = MAX_ENTRIES;
         }
-        List<WeblogEntryComment> recentComments = new ArrayList<WeblogEntryComment>();
         if (length < 1) {
-            return recentComments;
+            return Collections.emptyList();
         }
         try {
             WeblogEntryManager wmgr = WebloggerFactory.getWeblogger().getWeblogEntryManager();
@@ -714,11 +715,11 @@ public class Weblog implements Serializable {
             csc.setStatus(WeblogEntryComment.ApprovalStatus.APPROVED);
             csc.setReverseChrono(true);
             csc.setMaxResults(length);
-            recentComments = wmgr.getComments(csc);
+            return wmgr.getComments(csc);
         } catch (WebloggerException e) {
             log.error("ERROR: getting recent comments", e);
         }
-        return recentComments;
+        return Collections.emptyList();
     }
 
     
@@ -768,7 +769,6 @@ public class Weblog implements Serializable {
      * @return          Collection of WeblogEntryTag objects
      */
     public List<TagStat> getPopularTags(int sinceDays, int length) {
-        List<TagStat> results = new ArrayList<TagStat>();
         Date startDate = null;
         if(sinceDays > 0) {
             Calendar cal = Calendar.getInstance();
@@ -779,11 +779,11 @@ public class Weblog implements Serializable {
         try {            
             Weblogger roller = WebloggerFactory.getWeblogger();
             WeblogEntryManager wmgr = roller.getWeblogEntryManager();
-            results = wmgr.getPopularTags(this, startDate, 0, length);
+            return wmgr.getPopularTags(this, startDate, 0, length);
         } catch (Exception e) {
             log.error("ERROR: fetching popular tags for weblog " + this.getName(), e);
         }
-        return results;
+        return Collections.emptyList();
     }      
 
     public long getCommentCount() {
@@ -890,7 +890,7 @@ public class Weblog implements Serializable {
      */
     public boolean hasBookmarkFolder(String name) {
         for (WeblogBookmarkFolder folder : this.getBookmarkFolders()) {
-            if(name.toLowerCase().equals(folder.getName().toLowerCase())) {
+            if(name.equalsIgnoreCase(folder.getName())) {
                 return true;
             }
         }
